==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/network/kotlin/inputs/VirtualNetworkGatewayPolicyGroupArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.network.kotlin.inputs

import com.pulumi.azurenative.network.inputs.VirtualNetworkGatewayPolicyGroupArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Boolean
import kotlin.Int
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Parameters for VirtualNetworkGatewayPolicyGroup.
 * @property id Resource ID.
 * @property isDefault Shows if this is a Default VirtualNetworkGatewayPolicyGroup or not.
 * @property name The name of the resource that is unique within a resource group. This name can be used to access the resource.
 * @property policyMembers Multiple PolicyMembers for VirtualNetworkGatewayPolicyGroup.
 * @property priority Priority for VirtualNetworkGatewayPolicyGroup.
 */
public data class VirtualNetworkGatewayPolicyGroupArgs(
    public val id: Output<String>? = null,
    public val isDefault: Output<Boolean>,
    public val name: Output<String>? = null,
    public val policyMembers: Output<List<VirtualNetworkGatewayPolicyGroupMemberArgs>>,
    public val priority: Output<Int>,
) : ConvertibleToJava<com.pulumi.azurenative.network.inputs.VirtualNetworkGatewayPolicyGroupArgs> {
    override fun toJava(): com.pulumi.azurenative.network.inputs.VirtualNetworkGatewayPolicyGroupArgs =
        com.pulumi.azurenative.network.inputs.VirtualNetworkGatewayPolicyGroupArgs.builder()
            .id(id?.applyValue({ args0 -> args0 }))
            .isDefault(isDefault.applyValue({ args0 -> args0 }))
            .name(name?.applyValue({ args0 -> args0 }))
            .policyMembers(
                policyMembers.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .priority(priority.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [VirtualNetworkGatewayPolicyGroupArgs].
 */
@PulumiTagMarker
public class VirtualNetworkGatewayPolicyGroupArgsBuilder internal constructor() {
    private var id: Output<String>? = null

    private var isDefault: Output<Boolean>? = null

    private var name: Output<String>? = null

    private var policyMembers: Output<List<VirtualNetworkGatewayPolicyGroupMemberArgs>>? = null

    private var priority: Output<Int>? = null

    /**
     * @param value Resource ID.
     */
    @JvmName("efkhhpuvciutmueh")
    public suspend fun id(`value`: Output<String>) {
        this.id = value
    }

    /**
     * @param value Shows if this is a Default VirtualNetworkGatewayPolicyGroup or not.
     */
    @JvmName("pekmnauwgljguhsa")
    public suspend fun isDefault(`value`: Output<Boolean>) {
        this.isDefault = value
    }

    /**
     * @param value The name of the resource that is unique within a resource group. This name can be used to access the resource.
     */
    @JvmName("ipbpqomsfmufndbk")
    public suspend fun name(`value`: Output<String>) {
        this.name = value
    }

    /**
     * @param value Multiple PolicyMembers for VirtualNetworkGatewayPolicyGroup.
     */
    @JvmName("toieiylydypmttwx")
    public suspend
    fun policyMembers(`value`: Output<List<VirtualNetworkGatewayPolicyGroupMemberArgs>>) {
        this.policyMembers = value
    }

    @JvmName("iafvrequatvmlaov")
    public suspend fun policyMembers(
        vararg
        values: Output<VirtualNetworkGatewayPolicyGroupMemberArgs>,
    ) {
        this.policyMembers = Output.all(values.asList())
    }

    /**
     * @param values Multiple PolicyMembers for VirtualNetworkGatewayPolicyGroup.
     */
    @JvmName("oqydvuxcvbkbguky")
    public suspend
    fun policyMembers(values: List<Output<VirtualNetworkGatewayPolicyGroupMemberArgs>>) {
        this.policyMembers = Output.all(values)
    }

    /**
     * @param value Priority for VirtualNetworkGatewayPolicyGroup.
     */
    @JvmName("ccltrxfierkohhod")
    public suspend fun priority(`value`: Output<Int>) {
        this.priority = value
    }

    /**
     * @param value Resource ID.
     */
    @JvmName("ohfywhnndatqoviy")
    public suspend fun id(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.id = mapped
    }

    /**
     * @param value Shows if this is a Default VirtualNetworkGatewayPolicyGroup or not.
     */
    @JvmName("npnnlawftsijcexh")
    public suspend fun isDefault(`value`: Boolean) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.isDefault = mapped
    }

    /**
     * @param value The name of the resource that is unique within a resource group. This name can be used to access the resource.
     */
    @JvmName("nlmjamgxemjyfskl")
    public suspend fun name(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.name = mapped
    }

    /**
     * @param value Multiple PolicyMembers for VirtualNetworkGatewayPolicyGroup.
     */
    @JvmName("kfdpfglqrxrymkau")
    public suspend fun policyMembers(`value`: List<VirtualNetworkGatewayPolicyGroupMemberArgs>) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.policyMembers = mapped
    }

    /**
     * @param argument Multiple PolicyMembers for VirtualNetworkGatewayPolicyGroup.
     */
    @JvmName("umjmxujftgmtlske")
    public suspend
    fun policyMembers(argument: List<suspend VirtualNetworkGatewayPolicyGroupMemberArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            VirtualNetworkGatewayPolicyGroupMemberArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.policyMembers = mapped
    }

    /**
     * @param argument Multiple PolicyMembers for VirtualNetworkGatewayPolicyGroup.
     */
    @JvmName("isclgiuwgqskesee")
    public suspend fun policyMembers(
        vararg
        argument: suspend VirtualNetworkGatewayPolicyGroupMemberArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            VirtualNetworkGatewayPolicyGroupMemberArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.policyMembers = mapped
    }

    /**
     * @param argument Multiple PolicyMembers for VirtualNetworkGatewayPolicyGroup.
     */
    @JvmName("banawcfaglcgjrtl")
    public suspend
    fun policyMembers(argument: suspend VirtualNetworkGatewayPolicyGroupMemberArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(
            VirtualNetworkGatewayPolicyGroupMemberArgsBuilder().applySuspend {
                argument()
            }.build(),
        )
        val mapped = of(toBeMapped)
        this.policyMembers = mapped
    }

    /**
     * @param values Multiple PolicyMembers for VirtualNetworkGatewayPolicyGroup.
     */
    @JvmName("cbrhhjvtcxawenjm")
    public suspend fun policyMembers(vararg values: VirtualNetworkGatewayPolicyGroupMemberArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.policyMembers = mapped
    }

    /**
     * @param value Priority for VirtualNetworkGatewayPolicyGroup.
     */
    @JvmName("evjcalaydyksidvd")
    public suspend fun priority(`value`: Int) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.priority = mapped
    }

    internal fun build(): VirtualNetworkGatewayPolicyGroupArgs = VirtualNetworkGatewayPolicyGroupArgs(
        id = id,
        isDefault = isDefault ?: throw PulumiNullFieldException("isDefault"),
        name = name,
        policyMembers = policyMembers ?: throw PulumiNullFieldException("policyMembers"),
        priority = priority ?: throw PulumiNullFieldException("priority"),
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/network/kotlin/inputs/VirtualNetworkGatewayPolicyGroupArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.network.kotlin.inputs

import com.pulumi.azurenative.network.inputs.VirtualNetworkGatewayPolicyGroupArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Boolean
import kotlin.Int
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Parameters for VirtualNetworkGatewayPolicyGroup.
 * @property id Resource ID.
 * @property isDefault Shows if this is a Default VirtualNetworkGatewayPolicyGroup or not.
 * @property name The name of the resource that is unique within a resource group. This name can be used to access the resource.
 * @property policyMembers Multiple PolicyMembers for VirtualNetworkGatewayPolicyGroup.
 * @property priority Priority for VirtualNetworkGatewayPolicyGroup.
 */
public data class VirtualNetworkGatewayPolicyGroupArgs(
    public val id: Output<String>? = null,
    public val isDefault: Output<Boolean>,
    public val name: Output<String>? = null,
    public val policyMembers: Output<List<VirtualNetworkGatewayPolicyGroupMemberArgs>>,
    public val priority: Output<Int>,
) : ConvertibleToJava<com.pulumi.azurenative.network.inputs.VirtualNetworkGatewayPolicyGroupArgs> {
    override fun toJava(): com.pulumi.azurenative.network.inputs.VirtualNetworkGatewayPolicyGroupArgs =
        com.pulumi.azurenative.network.inputs.VirtualNetworkGatewayPolicyGroupArgs.builder()
            .id(id?.applyValue({ args0 -> args0 }))
            .isDefault(isDefault.applyValue({ args0 -> args0 }))
            .name(name?.applyValue({ args0 -> args0 }))
            .policyMembers(
                policyMembers.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .priority(priority.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [VirtualNetworkGatewayPolicyGroupArgs].
 */
@PulumiTagMarker
public class VirtualNetworkGatewayPolicyGroupArgsBuilder internal constructor() {
    private var id: Output<String>? = null

    private var isDefault: Output<Boolean>? = null

    private var name: Output<String>? = null

    private var policyMembers: Output<List<VirtualNetworkGatewayPolicyGroupMemberArgs>>? = null

    private var priority: Output<Int>? = null

    /**
     * @param value Resource ID.
     */
    @JvmName("dkfnwkpcmfgpgqnv")
    public suspend fun id(`value`: Output<String>) {
        this.id = value
    }

    /**
     * @param value Shows if this is a Default VirtualNetworkGatewayPolicyGroup or not.
     */
    @JvmName("mpwxgbrbqtmedube")
    public suspend fun isDefault(`value`: Output<Boolean>) {
        this.isDefault = value
    }

    /**
     * @param value The name of the resource that is unique within a resource group. This name can be used to access the resource.
     */
    @JvmName("xmhxmbotxwahmyui")
    public suspend fun name(`value`: Output<String>) {
        this.name = value
    }

    /**
     * @param value Multiple PolicyMembers for VirtualNetworkGatewayPolicyGroup.
     */
    @JvmName("bjncrqoyspvmbveb")
    public suspend
    fun policyMembers(`value`: Output<List<VirtualNetworkGatewayPolicyGroupMemberArgs>>) {
        this.policyMembers = value
    }

    @JvmName("eyfbuaatspikmmox")
    public suspend fun policyMembers(
        vararg
        values: Output<VirtualNetworkGatewayPolicyGroupMemberArgs>,
    ) {
        this.policyMembers = Output.all(values.asList())
    }

    /**
     * @param values Multiple PolicyMembers for VirtualNetworkGatewayPolicyGroup.
     */
    @JvmName("nffwlleokkigctjx")
    public suspend
    fun policyMembers(values: List<Output<VirtualNetworkGatewayPolicyGroupMemberArgs>>) {
        this.policyMembers = Output.all(values)
    }

    /**
     * @param value Priority for VirtualNetworkGatewayPolicyGroup.
     */
    @JvmName("gsqidaxchhvvkbjy")
    public suspend fun priority(`value`: Output<Int>) {
        this.priority = value
    }

    /**
     * @param value Resource ID.
     */
    @JvmName("fxnxelofjgfgafdl")
    public suspend fun id(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.id = mapped
    }

    /**
     * @param value Shows if this is a Default VirtualNetworkGatewayPolicyGroup or not.
     */
    @JvmName("whqkmihnqldyndfa")
    public suspend fun isDefault(`value`: Boolean) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.isDefault = mapped
    }

    /**
     * @param value The name of the resource that is unique within a resource group. This name can be used to access the resource.
     */
    @JvmName("heabmrvogjdbwnvo")
    public suspend fun name(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.name = mapped
    }

    /**
     * @param value Multiple PolicyMembers for VirtualNetworkGatewayPolicyGroup.
     */
    @JvmName("vdjqxjoayjobcdyd")
    public suspend fun policyMembers(`value`: List<VirtualNetworkGatewayPolicyGroupMemberArgs>) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.policyMembers = mapped
    }

    /**
     * @param argument Multiple PolicyMembers for VirtualNetworkGatewayPolicyGroup.
     */
    @JvmName("gamocxkiqqdqyuaw")
    public suspend
    fun policyMembers(argument: List<suspend VirtualNetworkGatewayPolicyGroupMemberArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            VirtualNetworkGatewayPolicyGroupMemberArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.policyMembers = mapped
    }

    /**
     * @param argument Multiple PolicyMembers for VirtualNetworkGatewayPolicyGroup.
     */
    @JvmName("viuemfrnujwxfoxm")
    public suspend fun policyMembers(
        vararg
        argument: suspend VirtualNetworkGatewayPolicyGroupMemberArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            VirtualNetworkGatewayPolicyGroupMemberArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.policyMembers = mapped
    }

    /**
     * @param argument Multiple PolicyMembers for VirtualNetworkGatewayPolicyGroup.
     */
    @JvmName("qeyhlecvqavyvqqa")
    public suspend
    fun policyMembers(argument: suspend VirtualNetworkGatewayPolicyGroupMemberArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(
            VirtualNetworkGatewayPolicyGroupMemberArgsBuilder().applySuspend {
                argument()
            }.build(),
        )
        val mapped = of(toBeMapped)
        this.policyMembers = mapped
    }

    /**
     * @param values Multiple PolicyMembers for VirtualNetworkGatewayPolicyGroup.
     */
    @JvmName("jwftbhdgsffpanto")
    public suspend fun policyMembers(vararg values: VirtualNetworkGatewayPolicyGroupMemberArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.policyMembers = mapped
    }

    /**
     * @param value Priority for VirtualNetworkGatewayPolicyGroup.
     */
    @JvmName("njlrludesbculrgy")
    public suspend fun priority(`value`: Int) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.priority = mapped
    }

    internal fun build(): VirtualNetworkGatewayPolicyGroupArgs = VirtualNetworkGatewayPolicyGroupArgs(
        id = id,
        isDefault = isDefault ?: throw PulumiNullFieldException("isDefault"),
        name = name,
        policyMembers = policyMembers ?: throw PulumiNullFieldException("policyMembers"),
        priority = priority ?: throw PulumiNullFieldException("priority"),
    )
}
